@@ -2,28 +2,29 @@ current_sections <- c(
   "AM_WARP_MAP", "DG_HiCap", "DG_Viewer", "DG_Well_Driller", "DW_Map_Cached",
   "DW_Map_Dynamic", "ER_Biotics", "ER_Bird_Breeding_Atlas", "FM_Trout",
   "LF_DML", "PR_TRAILS", "RR_Sites_Map", "WM_CWD", "WM_LMS", "WM_VPA",
-  "WT_Condition_Viewer", "WT_SWDV", "WT_TMDL", "WY_Lakes_AIS", "WY_PRESTO",
-  "CS_Offices", "FN_FLEET", "FR_IFFRS", "FR_IFFRS_TRN", "FR_WIS_BURN",
+  "WM_WSHED", "WT_Condition_Viewer", "WT_SWDV", "WT_TMDL", "WY_Lakes_AIS",
+  "WY_PRESTO", "CS_Offices", "DG_Groundwater_Retrieval_Network", "EM_PFAS",
+  "FN_FLEET", "FR_IFFRS", "FR_IFFRS_TRN", "FR_WIGO_MAP", "FR_WIS_BURN",
   "LF_Master_Planning", "OGW_Beach_Monitoring", "TS_AGOL_STAGING_SERVICES",
-  "WA_Waste", "WM_APIP", "WY_Wastewater", "WY_WETLAND", "DW_Elevation",
-  "DW_Image", "DW_Land_Cover", "FR_URBAN_FORESTRY"
+  "WA_Waste", "WM_APIP", "WT_DAM", "WT_SW_PERMIT", "WY_Wastewater",
+  "WY_WETLAND", "DW_Elevation", "DW_Imagery", "DW_Land_Cover",
+  "FR_URBAN_FORESTRY"
 )
 trout_services <- c(
-  "FM_TROUT_ANNO_WTM_Ext", "FM_TROUT_COUNTY_REGS_WTM",
-  "FM_TROUT_HAB_SITES_WTM_Ext", "FM_TROUT_NONDNR_EASEMENTS_WTM_Ext",
-  "FM_TROUT_REGS_WTM_Ext"
+  "FM_TROUT_ANNO_WTM_Ext", "FM_TROUT_HAB_SITES_WTM_Ext",
+  "FM_TROUT_NONDNR_EASEMENTS_WTM_Ext", "FM_TROUT_REGS_WTM_Ext"
 )
 
 
 test_that("list_sections works appropriately", {
   sections <- list_sections()
-  expect_length(sections, 36)
+  expect_length(sections, length(current_sections))
   expect_equal(sections, current_sections)
 })
 
 test_that("list_services works appropriately", {
   services <- list_services(section = "FM_Trout")
-  expect_length(services, 5)
+  expect_length(services, length(trout_services))
   expect_equal(services, trout_services)
 })
 
@@ -50,17 +51,17 @@ test_that("list_urls works appropriately", {
   trout_anno_urls <- list_urls(services = trout_services[1])
   trout_anno2_url <- paste0(
     "https://dnrmaps.wi.gov/arcgis/rest/services/FM_Trout/",
-    "FM_TROUT_COUNTY_REGS_WTM/MapServer/0"
+    "FM_TROUT_NONDNR_EASEMENTS_WTM_Ext/MapServer/0"
   )
   expect_length(trout_anno_urls, 2)
-  expect_equal(list_urls(services = trout_services[2]), trout_anno2_url)
+  expect_equal(list_urls(services = trout_services[3]), trout_anno2_url)
   expect_true(nrow(list_urls(services = trout_services[1], pull = FALSE)) == 2)
   expect_true(ncol(list_urls(services = trout_services[1], pull = FALSE)) == 5)
 })
 
 test_that("match_sections works appropriately", {
   expect_equal(match_sections("trout"), "FM_Trout")
-  expect_length(match_sections("WT"), 3)
+  expect_length(match_sections("WT"), 5)
   expect_equal(match_sections("FR_IFFRS", exact = TRUE), "FR_IFFRS")
 })
 
@@ -75,11 +76,11 @@ test_that("match_services works appropriately", {
 })
 
 test_that("match_layers works appropriately", {
-  expect_length(match_layers("fish"), 38)
-  expect_length(match_layers("fish|trout"), 51)
+  expect_length(match_layers("fish"), 43)
+  expect_length(match_layers("fish|trout"), 56)
   expect_equal(match_layers("stream", sections = match_sections("Trout")),
-               "Trout Stream Regulations 2018-2019")
-  expect_equal(match_layers("Wild Rice", exact = TRUE), "Wild Rice")
+               "Trout Stream Regulations")
+  expect_equal(match_layers("Trout Waters", exact = TRUE), "Trout Waters")
 })
 
 test_that("argument checking functions return correct warnings", {
